---
name: Feature request
about: Suggest or request an enhancement

---

**Describe the feature or enhancement**
Be as descriptive and precise as possible.

**Provide a concrete example of how the feature or enhancement will improve `fastnumbers`**
Code examples are an excellent way to show how this feature or enhancement will help. To make your case stronger, show the current workaround due to the lack of the feature. What is the return-on-investment for including the feature or enhancement?

**Would you be willing to submit a Pull Request for this feature?**
Extra help is *always* welcome.
